# handyML

[![license](https://img.shields.io/github/license/leo6033/handyML)](LICENSE)

[Chinese version ReadME](README-CN.md)

## Content

- [Background](#Background)
- [Install](#Install)
- [Document](#Document)
- [License](#License)

## Background

A library for data science

## Install

- PyPI (pip):

> 

## Document



## License

[MIT © Richard McRichface.](LICENSE)



